import React, { useState, useEffect } from 'react';
import OrderIndexItem from './OrderIndexItem';
import { connect } from "react-redux";
import { createOrder, fetchOrders, editOrder } from '../../actions/order_actions';

const OrderIndex = ({
  orders,
  fetchOrders,
  createOrder,
  editOrder,
}) => {
  const [fetchAttempted, setFetchAttempted] = useState(false);

  useEffect(() => {
    if (!fetchAttempted) {
      setFetchAttempted(true);
      fetchOrders();
    }
  }, [fetchOrders, fetchAttempted])

  return (
    <div>
      <h1>Order Index</h1>
      <button onClick={createOrder}>Create New Order</button>
      <button onClick={editOrder}>Update Order</button>

      <br />
      <br />

      {orders.allIds.map((orderId) => {
        const order = orders.byId[orderId];
        return <OrderIndexItem key={order.id} order={order} />;
      })}
    </div>
  );

}

const mapStateToProps = (state) => ({
  orders: state.entities.orders,
})

const mapDispatchToProps = dispatch => ({
  fetchOrders: () => dispatch(fetchOrders()),
  createOrder: order => dispatch(createOrder(order)),
  editOrder: order => dispatch(editOrder(order)),
})

export default connect(mapStateToProps, mapDispatchToProps)(OrderIndex)
